# -*- coding: utf-8 -*-

# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.


TRAITS = [
    # ref: https://en.wikipedia.org/wiki/Streaming_SIMD_Extensions
    'AVX',
    'AVX2',
    'CLMUL',
    'FMA3',
    'FMA4',
    'F16C',
    'MMX',
    'SSE',
    'SSE2',
    'SSE3',
    'SSSE3',
    'SSE41',
    'SSE42',
    'SSE4A',
    'XOP',
    '3DNOW',

    # ref: https://en.wikipedia.org/wiki/AVX-512
    'AVX512F',  # foundation
    'AVX512CD',  # conflict detection
    'AVX512PF',  # prefetch
    'AVX512ER',  # exponential + reciprocal
    'AVX512VL',  # vector length extensions
    'AVX512BW',  # byte + word
    'AVX512DQ',  # double word + quad word
    # ref: https://en.wikipedia.org/wiki/Bit_Manipulation_Instruction_Sets
    'ABM',
    'BMI',
    'BMI2',
    'TBM',
    # ref: https://en.wikipedia.org/wiki/AES_instruction_set
    'AESNI',
    # ref: https://en.wikipedia.org/wiki/Intel_SHA_extensions
    'SHA',
    # ref: https://en.wikipedia.org/wiki/Intel_MPX
    'MPX',
    # ref: https://en.wikipedia.org/wiki/Software_Guard_Extensions
    'SGX',
    # ref:
    #    https://en.wikipedia.org/wiki/Transactional_Synchronization_Extensions
    'TSX',
    # ref: https://en.wikipedia.org/wiki/Advanced_Synchronization_Facility
    'ASF',
    # ref: https://en.wikipedia.org/wiki/VT-x
    'VMX',
    # ref: https://en.wikipedia.org/wiki/AMD-V
    'SVM',
]



# -*- coding: utf-8 -*-

# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.


TRAITS = [
    # ref: https://en.wikipedia.org/wiki/Display_resolution
    'W320H240',
    'W640H480',
    'W800H600',
    'W1024H600',
    'W1024H768',
    'W1152H864',
    'W1280H720',
    'W1280H768',
    'W1280H800',
    'W1280H1024',
    'W1360H768',
    'W1366H768',
    'W1440H900',
    'W1600H900',
    'W1600H1200',
    'W1680H1050',
    'W1920H1080',
    'W1920H1200',
    'W2560H1440',
    'W2560H1600',
    'W3840H2160',
    'W7680H4320',
]



# -*- coding: utf-8 -*-

# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.


TRAITS = [
    # ref: https://en.wikipedia.org/wiki/DirectX
    'DIRECTX_V10',
    'DIRECTX_V11',
    'DIRECTX_V12',
    # ref: https://en.wikipedia.org/wiki/Direct2D
    'DIRECT2D',
    # ref: https://en.wikipedia.org/wiki/Direct3D
    'DIRECT3D_V6_0',
    'DIRECT3D_V7_0',
    'DIRECT3D_V8_0',
    'DIRECT3D_V8_1',
    'DIRECT3D_V9_0',
    'DIRECT3D_V9_0B',
    'DIRECT3D_V9_0C',
    'DIRECT3D_V9_0L',
    'DIRECT3D_V10_0',
    'DIRECT3D_V10_1',
    'DIRECT3D_V11_0',
    'DIRECT3D_V11_1',
    'DIRECT3D_V11_2',
    'DIRECT3D_V11_3',
    'DIRECT3D_V12_0',
    # ref: https://en.wikipedia.org/wiki/Vulkan_(API)
    'VULKAN',
    # ref: https://en.wikipedia.org/wiki/DirectX_Video_Acceleration
    'DXVA',
    # ref: https://en.wikipedia.org/wiki/OpenCL
    'OPENCL_V1_0',
    'OPENCL_V1_1',
    'OPENCL_V1_2',
    'OPENCL_V2_0',
    'OPENCL_V2_1',
    'OPENCL_V2_2',
    # ref: https://en.wikipedia.org/wiki/OpenGL
    'OPENGL_V1_1',
    'OPENGL_V1_2',
    'OPENGL_V1_3',
    'OPENGL_V1_4',
    'OPENGL_V1_5',
    'OPENGL_V2_0',
    'OPENGL_V2_1',
    'OPENGL_V3_0',
    'OPENGL_V3_1',
    'OPENGL_V3_2',
    'OPENGL_V3_3',
    'OPENGL_V4_0',
    'OPENGL_V4_1',
    'OPENGL_V4_2',
    'OPENGL_V4_3',
    'OPENGL_V4_4',
    'OPENGL_V4_5',
    # ref: https://en.wikipedia.org/wiki/CUDA
    'CUDA_V1_0',
    'CUDA_V1_1',
    'CUDA_V1_2',
    'CUDA_V1_3',
    'CUDA_V2_0',
    'CUDA_V2_1',
    'CUDA_V3_0',
    'CUDA_V3_2',
    'CUDA_V3_5',
    'CUDA_V3_7',
    'CUDA_V5_0',
    'CUDA_V5_2',
    'CUDA_V5_3',
    'CUDA_V6_0',
    'CUDA_V6_1',
    'CUDA_V6_2',
    'CUDA_V7_0',
    'CUDA_V7_1',
]



# -*- coding: utf-8 -*-

# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

TRAITS = [
    # Indicates that the resource provider decorated with this trait exposes
    # its resources for consumption on *other* resource providers via an
    # aggregate association. The canonical example here would be a shared
    # storage pool.
    #
    # The deployer might create a resource provider, let's call it "NFS_SHARE"
    # that has an inventory record of 2000 total DISK_GB resources.
    #
    # There may be 10 other resource providers, let's call them "CN_1" through
    # "CN_10" that represent compute nodes. These compute node resource
    # providers have inventory records for MEMORY_MB and VCPU resources, but no
    # DISK_GB inventory.
    #
    # Both the "NFS_SHARE" resource provider and each of the "CN_x" resource
    # providers are associated to the same aggregate, let's call it "AGG_A".
    #
    # Deployers would decorate the "NFS_SHARE" resource provider with the
    # "MISC_SHARES_VIA_AGGREGATE" trait to indicate to the system that the
    # DISK_GB inventory it provides can be consumed by consumers of resources
    # on any of the other resource providers associated with any aggregate
    # "NFS_SHARE" is associated to.
    'SHARES_VIA_AGGREGATE',
]
